@@ -222,7 +222,57 @@ Problems with this stuff:
   3) A multi-connector must be either all "outside" or all "inside" the and.
      For example, "the big black dog and cat ran" has only two ways to
      linkages (instead of three).
- 
+
+Possible bug: It seems that the following two linkages should be the
+same under the canonical linkage test.  Could this have to do with the
+pluralization system?
+
+> I am big and the bike and the car were broken
+Accepted (4 linkages, 4 with no P.P. violations) at stage 1
+  Linkage 1, cost vector = (0, 0, 18)
+
+                                   +------Spx-----+      
+       +-----CC-----+------Wd------+-d^^*i^-+     |      
+  +-Wd-+Spi+-Pa+    |   +--Ds-+d^^*+   +-Ds-+     +--Pv-+
+  |    |   |   |    |   |     |    |   |    |     |     |
+///// I.p am big.a and the bike.n and the car.n were broken 
+
+       /////          RW      <---RW---->  RW        /////
+       /////          Wd      <---Wd---->  Wd        I.p
+       I.p            CC      <---CC---->  CC        and
+       I.p            Sp*i    <---Spii-->  Spi       am
+       am             Pa      <---Pa---->  Pa        big.a
+       and            Wd      <---Wd---->  Wd        and
+       bike.n         d^s**  6<---d^^*i->  d^^*i  6  and
+       the            D       <---Ds---->  Ds        bike.n
+       and            Sp      <---Spx--->  Spx       were
+       and            d^^*i  6<---d^^*i->  d^s**  6  car.n
+       the            D       <---Ds---->  Ds        car.n
+       were           Pv      <---Pv---->  Pv        broken
+
+(press return for another)
+> 
+  Linkage 2, cost vector = (0, 0, 18)
+
+                                   +------Spx-----+      
+       +-----CC-----+------Wd------+-d^s**^-+     |      
+  +-Wd-+Spi+-Pa+    |   +--Ds-+d^s*+   +-Ds-+     +--Pv-+
+  |    |   |   |    |   |     |    |   |    |     |     |
+///// I.p am big.a and the bike.n and the car.n were broken 
+
+       /////          RW      <---RW---->  RW        /////
+       /////          Wd      <---Wd---->  Wd        I.p
+       I.p            CC      <---CC---->  CC        and
+       I.p            Sp*i    <---Spii-->  Spi       am
+       am             Pa      <---Pa---->  Pa        big.a
+       and            Wd      <---Wd---->  Wd        and
+       bike.n         d^s**  6<---d^s**->  d^s**  6  and
+       the            D       <---Ds---->  Ds        bike.n
+       and            Sp      <---Spx--->  Spx       were
+       and            d^s**  6<---d^s**->  d^s**  6  car.n
+       the            D       <---Ds---->  Ds        car.n
+       were           Pv      <---Pv---->  Pv        broken
+
 */
 
 typedef struct label_node_struct Label_node;
