@@ -1801,7 +1801,7 @@ void main(int argc, char** argv) {
     printf("\n %d words stored in %d bytes\n\n\n", N_dict, space_in_use);
 
     printf("\
-                Welcome to the Link Parser -- Verson 2                       \n\
+                Welcome to the Link Parser -- Version 2.1                     \n\
                         (Compiled %s)                     \n\
          \n", __DATE__);
     printf("          ");
