@@ -43,6 +43,14 @@
 
 */
 
+#define NO_ISLANDS TRUE
+
+/* If this is FALSE, then linkages in which an island of words appear
+   that are separate from the rest of the sentence are allowed.  If it
+   is TRUE, then these are not allwed.  The current post processing
+   system eliminates all linkages with islands, so for efficiency sake
+   it makes sense to leave this set to TRUE.  */
+
 int match(Connector *a, Connector *b) {
   /* 
      Returns TRUE if s and t match according to the connector matching
@@ -251,14 +259,24 @@ int count(int lw, int rw, Connector *le, Connector *re, int cost) {
 	/* you can't have a linkage here with cost > 0 */
 	if ((le == NULL) && (re == NULL) && (cost == 0)) {
 	    t->count = 1;
-	    return 1;
 	} else {
 	    t->count = 0;
-	    return t->count;
 	}
+	return t->count;
     }
     
     if ((le == NULL) && (re == NULL)) {
+#if NO_ISLANDS
+	/* if we don't allow islands (a set of words linked together but
+	   separate from the rest of the sentence) then  the cost of skipping
+	   n words is just n */
+	if (cost == rw-lw-1) {
+	    t->count = 1;
+	} else {
+	    t->count = 0;
+	}
+	return t->count;
+#else
 	if (cost == 0) {
 	    /* there is no zero-cost solution in this case */
 	    /* slight efficiency hack to separate this cost=0 case out */
@@ -276,6 +294,7 @@ int count(int lw, int rw, Connector *le, Connector *re, int cost) {
 	    t->count = total;
 	}
 	return t->count;
+#endif	    
     }
     
     if (le == NULL) {
@@ -370,6 +389,34 @@ int count(int lw, int rw, Connector *le, Connector *re, int cost) {
     return total;
 }
 
+/*
+To: Danny Sleator <sleator@CS.cmu.edu>
+From: John Lafferty <lafferty@CS.cmu.edu>
+Subject: improved parse procedure
+Mime-Version: 1.0
+Content-Type: text/plain; charset=us-ascii
+Date: Mon, 08 Jan 1996 19:13:23 -0500
+Message-ID: <27437.821146403@HARROLD.IS.CS.CMU.EDU>
+Sender: John_Lafferty@HARROLD.IS.CS.CMU.EDU
+
+
+Danny,
+
+Here's another, equivalent way of writing the "parse" procedure in your
+version of the code with null links (e.g., the release version):
+
+int parse(int cost) {
+    return count(-1, N_words, NULL, NULL, cost+1);
+}
+
+I'm making pretty good progress on writing the inside/outside
+training.  I have the basic routines written and working with 
+dummy procedures for the probabilities (but these procedures 
+are the hard part!).
+
+John
+*/
+
 int parse(int cost) {
     /* Returns the number of ways the sentence can be parsed with the
        specified cost Assumes that the hash table has already been
