@@ -97,7 +97,7 @@ static char * domain_starter_links[] =
                 "Ss#d", "Bsd", "ER", "Z", 
                 "Ma", "SIs#g", 
 		"BIqx", "MX#p", "MX#a", "MX#r", "MX#j", "MV#o", "MV#p",
-		"Eq", "COq", "CCq", "AFd", "PFc",
+		"Eq", "COq", "CP", "AFd", "PFc",
 		NULL};
   /* these links start a domain */
   /* each of these must be given a name in CDNP below */
@@ -130,13 +130,13 @@ CDNP CDNP_array[] = {{"Ce", 'e'}, {"R", 'r'}, {"Re", 'r'}, {"W", 'm'},
 		       {"Ss#d", 's'}, 
                        {"Bsd", 's'}, {"ER", 's'}, {"Z", 's'},
                        {"Ma", 'e'}, {"MX#p", 'e'}, {"Ci", 'e'}, {"MX#a", 'e'},
-		       {"Eq", 'e'}, {"COq", 'e'}, {"CCq", 'd'},
+		       {"Eq", 'e'}, {"COq", 'e'}, {"CP", 'd'},
 		       {"MX#r", 'r'}, 
        		       {NULL, 0}};
 
 static char * domain_contains_links[] = {"Mg", "Mx", "Bsd", 
 "MX#a", "Ma", "Mv", "MX#r", 
-"Ss#d", "CCq", "Ws", "Wq", "Qd", "Mj", "Wj", "Wi",
+"Ss#d", "CP", "Ws", "Wq", "Qd", "Mj", "Wj", "Wi",
 "MX#j", "AFd", "PFc", "Jr", "Wd", NULL};
   /* these links start a domain and they're also part of the domain */
   /* this must be a sublist of the domain_starter_list */
@@ -152,7 +152,7 @@ static char * must_be_connected_without[] = {"R*",
 
 static char * restricted_links[] = {"B#*", 
 "D##w", "B#w", "B#d", "AFh",
-     "MVt", "Xx", "HL", "SFsic", "AFd", "Bc", "CX", 
+     "MVt", "Xx", "HL", "SFsic", "AFd", "Bc", "CX", "CP",
      "EAh", "H", "HA", "PFc", "B#j", "Wd", "PF", "Z", NULL};
   /* these links are not traced further if they point back 
      before the root word */
@@ -818,7 +818,7 @@ static char * incompat_with_THi[] =  {"I*", "PP*", "TO*", "Pa*", "Pam",
 	  NULL};
 static char * SFiSFIi[] =  {"SFsi", "SFIsi", "OXi", NULL};
 static char * Necessary_for_SF[] =  {"TOi", "THi", "QIi",  
-          "TSi", "O#i", "Ci", "THb", "COqi", "CCqi", "Eqi", "AFdi", NULL};
+          "TSi", "O#i", "Ci", "THb", "COqi", "CPi", "Eqi", "AFdi", NULL};
 static char * Necessary_for_MVt[] = {"Dm#m", "EAm", "EEm", "MVm", 
 	  "Pam", "Pafm", "AFm", "EB#m", "MVb", "Om", "Mam", 
 	  "Am", "Jm", "Ds*m", NULL};
@@ -1006,7 +1006,7 @@ PP_node * post_process(void){
     PP(!contains_none("Ws", Incompat_with_Ws), "question inversion violated");
     PP(!contains_one("Ws", Nec_for_Ws_2),   "question inversion violated");
 
-    PP(!contains_one("Ia", Nec_for_Ia),"incorrect use of 'to'"); 
+    PP(!contains_one("I#a", Nec_for_Ia),"incorrect use of 'to'"); 
 
     PP(!contains_one("Wq", Nec_for_Wq),"question inversion violated");
     PP(!contains_one("Qd", Nec_for_Wq),"question inversion violated");
@@ -1033,7 +1033,7 @@ PP_node * post_process(void){
     PP(!contains_one("TOi", SFiSFIi),"TV rule 1 violated");
     PP(!contains_one("Ci", SFiSFIi),"Ci rule 1 violated");
     PP(!contains_one("COqi", SFiSFIi),"It rules violated");
-    PP(!contains_one("CCqi", SFiSFIi),"It rules violated");
+    PP(!contains_one("CPi", SFiSFIi),"It rules violated");
     PP(!contains_one("Eqi", SFiSFIi),"It rules violated");
     PP(!contains_one("LEi", SFiSFIi),"THi rule 1 violated");
     PP(!contains_one("MVti", SFiSFIi),"THi rule 1 violated");
